==> vue-infinite-loading-2.4.2.tgz: package/README.md <==
<p align="center"><img width="200" src="http://www.peachis.me/assets/vue-infinite-loading/logo.png"></p>
<p align="center">
  <a href="https://travis-ci.org/PeachScript/vue-infinite-loading"><img src="https://img.shields.io/travis/PeachScript/vue-infinite-loading/master.svg"></a>
  <a href="https://codecov.io/github/PeachScript/vue-infinite-loading?branch=master"><img src="https://img.shields.io/codecov/c/github/PeachScript/vue-infinite-loading/master.svg"></a>
  <a href="https://www.npmjs.com/package/vue-infinite-loading"><img src="https://img.shields.io/npm/dm/vue-infinite-loading.svg"></a>
  <a href="https://www.npmjs.com/package/vue-infinite-loading"><img src="https://img.shields.io/npm/v/vue-infinite-loading.svg"></a>
  <a href="https://www.npmjs.com/package/vue-infinite-loading"><img src="https://img.shields.io/npm/l/vue-infinite-loading.svg"></a>
</p>
<p align="center"><img src="http://www.peachis.me/assets/vue-infinite-loading/demo.gif"></p>

## Intro
An infinite scroll plugin for Vue.js, it can help you implement infinite scroll list more easily.

### Features
- Mobile friendly
- Internal spinners
- 2-directions support
- Load result message display

## Usage & Guide
To check out live examples and docs, visit [Vue-infinite-loading GitHub Pages](https://peachscript.github.io/vue-infinite-loading/).

## Changelog
Details changes for each release are documented in the [release notes](https://github.com/PeachScript/vue-infinite-loading/releases).

## Contribution
Please make sure to read the [Contributing Guide](https://github.com/PeachScript/vue-infinite-loading/blob/master/.github/CONTRIBUTING.md) before making a pull request.

## Licence
The MIT License (MIT)

Copyright (c) 2016-present PeachScript

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

==> vue-infinite-loading-2.4.4.tgz: package/README.md <==
<p align="center"><img width="200" src="http://www.peachis.me/assets/vue-infinite-loading/logo.png"></p>
<p align="center">
  <a href="https://travis-ci.org/PeachScript/vue-infinite-loading"><img src="https://img.shields.io/travis/PeachScript/vue-infinite-loading/master.svg"></a>
  <a href="https://codecov.io/github/PeachScript/vue-infinite-loading?branch=master"><img src="https://img.shields.io/codecov/c/github/PeachScript/vue-infinite-loading/master.svg"></a>
  <a href="https://www.npmjs.com/package/vue-infinite-loading"><img src="https://img.shields.io/npm/dm/vue-infinite-loading.svg"></a>
  <a href="https://www.npmjs.com/package/vue-infinite-loading"><img src="https://img.shields.io/npm/v/vue-infinite-loading.svg"></a>
  <a href="https://www.npmjs.com/package/vue-infinite-loading"><img src="https://img.shields.io/npm/l/vue-infinite-loading.svg"></a>
</p>
<p align="center"><img src="http://www.peachis.me/assets/vue-infinite-loading/demo.gif"></p>

## Intro
An infinite scroll plugin for Vue.js, to help you implement an infinite scroll list more easily.

### Features
- Mobile friendly
- Internal spinners
- 2-directional support
- Load result message display

## Usage & Guide
To check out live examples and docs, visit [Vue-infinite-loading GitHub Pages](https://peachscript.github.io/vue-infinite-loading/).

## Changelog
Detailed changes for each release are documented in the [release notes](https://github.com/PeachScript/vue-infinite-loading/releases).

## Contribution
Please make sure to read the [Contributing Guide](https://github.com/PeachScript/vue-infinite-loading/blob/master/.github/CONTRIBUTING.md) before making a pull request.

## Licence
The MIT License (MIT)

Copyright (c) 2016-present PeachScript

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
